@@ -647,6 +647,53 @@ _dbus_check_fdleaks_leave (DBusInitialFDs *fds,
 #endif
 }
 
+static void
+_dbus_test_help_page (const char *appname)
+{
+  fprintf(stdout, "%s [<options>] [<test-data-dir>] [<specific-test>]\n", appname);
+  fprintf(stdout, "Options:\n");
+  fprintf(stdout, "    --help         this page\n");
+  fprintf(stdout, "    --list-tests   show available tests\n");
+  fprintf(stdout, "    --tap          expect test data dir to be set by environment variable DBUS_TEST_DATA\n");
+  fprintf(stdout, "Environment variables:\n");
+  fprintf(stdout, "    DBUS_TEST_ONLY=<specific-test>    set specific test to run\n");
+  fprintf(stdout, "    DBUS_TEST_DATA=<test-data-dir>    set test data dir (required when using --tap)\n");
+}
+
+static void
+_dbus_test_show_available_tests (size_t n_tests,
+                                 const DBusTestCase *tests)
+{
+  size_t i;
+
+  for (i = 0; i < n_tests; i++)
+    {
+      if (tests[i].name == NULL)
+        break;
+
+      fprintf(stdout, "%s\n", tests[i].name);
+    }
+}
+
+static const DBusTestCase *
+_dbus_test_find_test (size_t n_tests,
+                      const DBusTestCase *tests,
+                      const char *specific_test)
+{
+  size_t i;
+
+  for (i = 0; i < n_tests; i++)
+    {
+      if (tests[i].name == NULL)
+        break;
+
+      if (strcmp (specific_test, tests[i].name) == 0)
+        return &tests[i];
+    }
+  return NULL;
+}
+
+
 /*
  * _dbus_test_main:
  * @argc: number of command-line arguments
@@ -684,6 +731,18 @@ _dbus_test_main (int                  argc,
   setlocale(LC_ALL, "");
 #endif
 
+  if (argc > 1 && strcmp (argv[1], "--help") == 0)
+    {
+      _dbus_test_help_page (argv[0]);
+      exit(0);
+    }
+
+  else if (argc > 1 && strcmp (argv[1], "--list-tests") == 0)
+    {
+      _dbus_test_show_available_tests (n_tests, tests);
+      exit (0);
+    }
+
   /* We can't assume that strings from _dbus_getenv() will remain valid
    * forever, because some tests call setenv(), which is allowed to
    * reallocate the entire environment block, and in Wine it seems that it
@@ -701,8 +760,11 @@ _dbus_test_main (int                  argc,
   if (test_data_dir != NULL)
     _dbus_test_diag ("Test data in %s", test_data_dir);
   else if (flags & DBUS_TEST_FLAGS_REQUIRE_DATA)
-    _dbus_test_fatal ("Must specify test data directory as argv[1] or "
-                      "in DBUS_TEST_DATA environment variable");
+    {
+      _dbus_test_help_page (argv[0]);
+      _dbus_test_fatal ("Must specify test data directory as argv[1] or "
+                        "in DBUS_TEST_DATA environment variable");
+    }
   else
     _dbus_test_diag ("No test data!");
 
@@ -711,6 +773,15 @@ _dbus_test_main (int                  argc,
   else
     specific_test = strdup0_or_die (_dbus_getenv ("DBUS_TEST_ONLY"));
 
+  /* check that test is present */
+  if (specific_test)
+    {
+      if (_dbus_test_find_test (n_tests, tests, specific_test) == NULL)
+        {
+          _dbus_test_fatal ("Invalid test name '%s' specified", specific_test);
+        }
+    }
+
   /* Some NSS modules like those for sssd and LDAP might allocate fds
    * on a one-per-process basis. Make sure those have already been
    * allocated before we enter the code under test, so that they don't
@@ -730,7 +801,7 @@ _dbus_test_main (int                  argc,
 
   for (i = 0; i < n_tests; i++)
     {
-      long before, after;
+      dbus_int64_t before, after;
       DBusInitialFDs *initial_fds = NULL;
 
       if (tests[i].name == NULL)
@@ -761,7 +832,7 @@ _dbus_test_main (int                  argc,
 
       _dbus_get_monotonic_time (&after, NULL);
 
-      _dbus_test_diag ("%s test took %ld seconds",
+      _dbus_test_diag ("%s test took %" DBUS_INT64_MODIFIER "d seconds",
                        tests[i].name, after - before);
 
       if (test_post_hook)
